yt.utilities.configuration\_tree module
=======================================

.. automodule:: yt.utilities.configuration_tree
   :members:
   :undoc-members:
   :inherited-members:
   :show-inheritance:
